==> delphixpy-1.8.2.0.tar.gz: delphixpy-1.8.2.0/delphixpy/v1_3_3/web/dvc/operation/operation.py <==
#
# Copyright 2017 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "dvc.operation"
"""
# pylint: disable=W0403,W0611,W0622
API_VERSION = "1.3.3"

import urllib
from delphixpy.v1_3_3 import response_validator

def get(engine, ref):
    """
    Retrieve the specified DVCOperation object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_3_3.delphix_engine.DelphixEngine`
    :param ref: Reference to a :py:class:`blackbox.web.vo.DVCOperation` object
    :type ref: ``str``
    :rtype: :py:class:`v1_3_3.web.vo.DVCOperation`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/dvc/operation/%s" % ref
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'DVCOperation'], returns_list=False, raw_result=raw_result)

def get_all(engine, application=None, branch=None):
    """
    Lists the DVC action history for a application.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_3_3.delphix_engine.DelphixEngine`
    :param application: Limit operations to the specific application. This
        option is mutually exclusive with the "branch" option.
    :type application: ``basestring``
    :param branch: Limit operations to the specified branch. This option is
        mutually exclusive with the "application" option.
    :type branch: ``basestring``
    :rtype: ``list`` of :py:class:`v1_3_3.web.vo.DVCOperation`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/dvc/operation"
    query_params = {"application": application, "branch": branch}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urllib.urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'DVCOperation'], returns_list=True, raw_result=raw_result)

==> delphixpy-1.9.0.0.tar.gz: delphixpy-1.9.0.0/delphixpy/v1_3_1/web/dvc/operation/operation.py <==
#
# Copyright 2017 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "dvc.operation"
"""
API_VERSION = "1.3.1"

import urllib
from delphixpy.v1_3_1 import response_validator

def get(engine, ref):
    """
    Retrieve the specified DVCOperation object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_3_1.delphix_engine.DelphixEngine`
    :param ref: Reference to a :py:class:`delphixpy.v1_3_1.web.vo.DVCOperation`
        object
    :type ref: ``str``
    :rtype: :py:class:`v1_3_1.web.vo.DVCOperation`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/dvc/operation/%s" % ref
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'DVCOperation'], returns_list=False, raw_result=raw_result)

def get_all(engine, application=None, branch=None):
    """
    Lists the DVC action history for a application.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_3_1.delphix_engine.DelphixEngine`
    :param application: Limit operations to the specific application. This
        option is mutually exclusive with the "branch" option.
    :type application: ``basestring``
    :param branch: Limit operations to the specified branch. This option is
        mutually exclusive with the "application" option.
    :type branch: ``basestring``
    :rtype: ``list`` of :py:class:`v1_3_1.web.vo.DVCOperation`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/dvc/operation"
    query_params = {"application": application, "branch": branch}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urllib.urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'DVCOperation'], returns_list=True, raw_result=raw_result)
